@@ -333,22 +333,16 @@ This is called if no specific handler exists"
 	     (chan-buffer (irchat-pick-buffer chnl)))
 
 	(irchat-w-insert chan-buffer
-			 (format "%3s %10s %9s <%s@%s>"
+			 (format "%3s %10s %9s %-29s%s\n"
 				 oper ;; Kaizzu 06/03/90
 				 (if (string= chnl "*") "Priv" ; *WORK* needed
 				   (if (string= chnl "0")
 				       "Priv"
 				     chnl))
 				 nick
-				 user
-				 (irchat-clean-hostname host)))
-	;; XXX: ugly, should be done above using format
-	(save-excursion
-	  (set-buffer (if (listp chan-buffer) (car chan-buffer) chan-buffer))
-	  (let ((buffer-read-only))
-	    (indent-to-column 54 1)
-	    (irchat-w-insert chan-buffer name)
-	    (irchat-w-insert chan-buffer "\n"))))
+				 (format "<%s@%s>" user
+					 (irchat-clean-hostname host))
+				 name)))
     (message "IRCHAT: Strange 352 message")))
 
 
@@ -407,10 +401,10 @@ don't display anything."
 (defun irchat-handle-364-msg (prefix rest)
   (if (string-match "^\\([^ ]+\\) +\\([^ ]*\\) +[^ ]* +:\\(.*\\)" rest)
       (progn
-	(irchat-w-insert irchat-300-buffer (matching-substring rest 2))
-	(indent-to-column 30)
-	(irchat-w-insert irchat-300-buffer (matching-substring rest 3))
-	(irchat-w-insert irchat-300-buffer "\n"))
+	(irchat-w-insert irchat-300-buffer 
+			 (format "%-30s%s\n"
+				 (matching-substring rest 2)
+				 (matching-substring rest 3))))
     (message "IRCHAT: Strange 364 message")))
 
 
