@@ -67,10 +67,7 @@
 	(if (fboundp (setq fun (intern
 				(concat "irchat-handle-" message "-msg"))))
 	  (progn
-	    (apply fun (list prefix rest-of-line))
-	    (if (not irchat-freeze)
-		(irchat-scroll-if-visible 
-		 (irchat-get-buffer-window (current-buffer)))))
+	    (apply fun (list prefix rest-of-line)))
 	  (let* ((message-number (string-to-int message))
 		 (default-number (/ message-number 100)))
 	    (if (and (> message-number 0)
@@ -79,10 +76,7 @@
 						 (format "%d00" default-number)
 						 "-msgs")))))
 		(progn
-		  (apply fun (list message-number prefix rest-of-line))
-		  (if (not irchat-freeze)
-		      (irchat-scroll-if-visible
-		       (irchat-get-buffer-window (current-buffer)))))
+		  (apply fun (list message-number prefix rest-of-line)))
 	      (message "IRCHAT: Unknown IRC message \":%s %s %s\"" prefix
 		       (upcase message) rest-of-line)
 	      (irchat-w-insert irchat-D-buffer 
@@ -117,10 +111,7 @@
 		     (buffer-substring (match-beginning 3) (match-end 3))))
 
       (set-buffer irchat-Dialogue-buffer)
-      (if irchat-freeze
-	  (save-excursion
-	    (irchat-handle-message-2 prefix message rest-of-line))
-	(irchat-handle-message-2 prefix message rest-of-line))
+      (irchat-handle-message-2 prefix message rest-of-line)
       (set-buffer obuf)
       (delete-region beg end))))
 
