@@ -15,10 +15,10 @@
 (defconst irchat-client-version-major "2"
   "Major version number. Major functional changes change this number.")
 
-(defconst irchat-client-version-minor "49"
+(defconst irchat-client-version-minor "50"
   "Minor version number. Server Protocol changes and bug fixes change this number.")
 
-(defconst irchat-client-version-release "$Date: 1995/01/15 15:38:02 $"
+(defconst irchat-client-version-release "$Date: 1995/03/25 22:22:22 $"
   "version release date")
 
 (defconst irchat-client-name "Irchat"
@@ -90,10 +90,6 @@ currently engaged in a one-to-one conversation.")
 (defvar irchat-polling 0
   "T when we are automatically polling the server.")
 
-(defvar irchat-freeze nil
-  "If non-nil the Dialogue window will not be scrolled automatically to bring
-new entries into view.")
-
 (defvar irchat-ownfreeze nil
   "If non-nil the Dialogue window will not be scrolled automatically to bring
 new entries into view when the user sends messages.")
