@@ -224,26 +224,25 @@ If optional argument SERVICE is non-nil, open by the service name."
 	(status nil))
     (setq irchat-status-message-string "")
     (cond ((and host (irchat-open-server-internal host service))
+	   (irchat-send "USER %s %s %s :%s"
+			(or (getenv "IRCUSER")
+			    (user-real-login-name))
+			(or (getenv "IRCHOST")
+			    irchat-system-fqdname)
+			irchat-server
+			(or (getenv "IRCNAME")
+			    (getenv "NAME")
+			    (user-full-name)))
+	   (setq irchat-old-nickname irchat-nickname)
+	   (setq irchat-nick-accepted 'sent)
+	   (irchat-send "NICK %s" irchat-nickname)
 	   (irchat-send "PING %s" host)
 	   (if (setq status (irchat-wait-for-response ".*PONG.*"))
 	       (progn
 		 (set-process-sentinel irchat-server-process
 				       'irchat-sentinel)
 		 (set-process-filter irchat-server-process
-				     'irchat-filter)
-		 (irchat-send "USER %s %s %s :%s"
-			      (or (getenv "IRCUSER")
-				  (user-real-login-name))
-			      (or (getenv "IRCHOST")
-				  irchat-system-fqdname)
-			      irchat-server
-			      (or (getenv "IRCNAME")
-				  (getenv "NAME")
-				  (user-full-name)))
-		 (setq irchat-old-nickname irchat-nickname)
-		 (setq irchat-nick-accepted 'sent)
-		 (irchat-send "NICK %s" irchat-nickname))
-
+				     'irchat-filter))
 	     ;; We have to close connection here, since the function
 	     ;;  `irchat-server-opened' may return incorrect status.
 	     (irchat-close-server-internal)))
@@ -388,6 +387,9 @@ For a list of the generic commands type \\[irchat-Command-generic] ? RET.
 	  irchat-ownfreeze-indicator "- " 
 	  irchat-nickname "@" irchat-server " %-"))
 
+  (if (irchat-frozen (car irchat-D-buffer))
+      (irchat-freeze-toggle (car irchat-D-buffer)))
+
   (use-local-map irchat-Command-mode-map)
   (if irchat-blink-parens
       nil
